@@ -430,6 +430,8 @@ public:
 
   std::string writeJsonTree(std::string filename = "", bool states = false);
 
+  std::string writeCsvTree(std::string filename = "", bool states = false);
+
   /**
    * Write tree to a .clu file.
    * @param filename the filename for the output file. If empty, use default
@@ -488,6 +490,12 @@ protected:
    */
   void writeJsonTree(std::ostream& outStream, bool states = false);
 
+  /**
+   * Write CSV tree to output stream
+   * @param states, write state-level tree, else aggregate physical nodes within modules
+   */
+  void writeCsvTree(std::ostream& outStream, bool states = false);
+
   InfoNode m_root;
   std::vector<InfoNode*> m_leafNodes;
   std::vector<InfoNode*> m_moduleNodes;
